## Plan Mode

- Make the plan extremely concise. Sacrifice grammar for the sake of being concise.
- At the end of each plan, give me a list of unresolved questions to answer, if any. Make the questions extremely concise.
- When in *plan mode*, you are writing the final plan as markdown file to `~/.claude/plans/` by default. When writing a plan to `~/.claude/plans/` you MUST always copy it to `./.claude/plans/` in the project root. For example, `~/.claude/plans/rosy-dancing-finch.md` should be copied to `./.claude/plans/rosy-dancing-finch.md`.
